@@ -331,11 +331,14 @@ class CommandLineTestCase(unittest.TestCase):
             self.assertEqual(ctx.returncode, 1)
 
     def test_run_with_locale(self):
-        self.addCleanup(locale.setlocale, locale.LC_ALL, 'C.UTF-8')
+        # check for availability of locale, otherwise skip the test
+        # reset to default before running the test,
+        # as the first two runs don't use setlocale()
         try:
             locale.setlocale(locale.LC_ALL, 'en_US.UTF-8')
         except locale.Error:
             self.skipTest('locale en_US.UTF-8 not available')
+        locale.setlocale(locale.LC_ALL, (None, None))
 
         # C + en.yaml should fail
         with RunContext(self) as ctx:
@@ -343,6 +346,16 @@ class CommandLineTestCase(unittest.TestCase):
                      os.path.join(self.wd, 'en.yaml')))
         self.assertEqual(ctx.returncode, 1)
 
+        # C + c.yaml should pass
+        with RunContext(self) as ctx:
+            cli.run(('-d', 'rules: { key-ordering: enable }',
+                    os.path.join(self.wd, 'c.yaml')))
+        self.assertEqual(ctx.returncode, 0)
+
+        # the next two runs use setlocale() inside,
+        # so we need to clean up afterwards
+        self.addCleanup(locale.setlocale, locale.LC_ALL, (None, None))
+
         # en_US + en.yaml should pass
         with RunContext(self) as ctx:
             cli.run(('-d', 'locale: en_US.UTF-8\n'
@@ -357,12 +370,6 @@ class CommandLineTestCase(unittest.TestCase):
                      os.path.join(self.wd, 'c.yaml')))
         self.assertEqual(ctx.returncode, 1)
 
-        # C + c.yaml should pass
-        with RunContext(self) as ctx:
-            cli.run(('-d', 'rules: { key-ordering: enable }',
-                    os.path.join(self.wd, 'c.yaml')))
-        self.assertEqual(ctx.returncode, 0)
-
     def test_run_version(self):
         with RunContext(self) as ctx:
             cli.run(('--version', ))
@@ -421,6 +428,14 @@ class CommandLineTestCase(unittest.TestCase):
     def test_run_non_ascii_file(self):
         path = os.path.join(self.wd, 'non-ascii', 'éçäγλνπ¥', 'utf-8')
 
+        # Make sure the default localization conditions on this "system"
+        # support UTF-8 encoding.
+        try:
+            locale.setlocale(locale.LC_ALL, (None, 'UTF-8'))
+        except locale.Error:
+            self.skipTest('no UTF-8 locale available')
+        self.addCleanup(locale.setlocale, locale.LC_ALL, (None, None))
+
         with RunContext(self) as ctx:
             cli.run(('-f', 'parsable', path))
         self.assertEqual((ctx.returncode, ctx.stdout, ctx.stderr), (0, '', ''))
